import java.awt.*;
import java.awt.event.*;

public class KochCurve extends Frame
{
   public static final int SLEEP_TIME = 1000;

   public KochCurve()
   {
      super( "Drawing Koch Curve" );
      setSize( 500, 500 );
      setVisible(true);
   }


  public void drawKochCurve( Graphics g, int n,
                             int x1, int y1,
                             int x2, int y2 )
  {
    if (n == 1)
       g.drawLine(x1, y1, x2, y2);
    else
    {
      int dx = (x2-x1)/3;
      int dy = (y2-y1)/3;
      int x3 = x1 + dx;
      int y3 = y1 + dy;
      int x4 = x3 + dx;
      int y4 = y3 + dy;
      int xMid = (x1+x2)/2;
      int yMid = (y1+y2)/2;
      int x5 = (int)(xMid + 0.866 * dy);
      int y5 = (int)(yMid - 0.866 * dx);
      drawKochCurve(g, n-1, x1, y1, x3, y3);
      drawKochCurve(g, n-1, x3, y3, x5, y5);
      drawKochCurve(g, n-1, x5, y5, x4, y4);
      drawKochCurve(g, n-1, x4, y4, x2, y2);
    }
  }//drawKochCurve


  public void paint(Graphics g)
  {
     for (int n = 1; n <= 7; n++) // draw 7 steps of the Koch curve
     {
       g.setColor(Color.WHITE);
       g.fillRect(0,0,500,500);  // erase the previous drawing
       g.setColor(Color.BLACK);
       drawKochCurve(g, n, 0, 250, 500, 250);
       // increase the following amount of delay to slow down the drawing
       try{ Thread.sleep(SLEEP_TIME); } catch (InterruptedException e){}
     }
  }//paint


   // The main method creates an instance of this class
   // thereby "running" this program.
   public static void main( String args[] )
   {
      KochCurve app = new KochCurve();
   }//main

}//KochCurve